skeleton

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2024 License: Apache-2.0 Imports: 0 Imported by: 0

README

skeleton: Template repository for Go packages in the cunicu organization

GitHub Workflow Status goreportcard Codecov branch License GitHub go.mod Go version Go Reference

This skeleton repo a template for new Go packages belonging to the cunicu organization.

Install

Usage

Contact

Please have a look at the contact page: cunicu.li/docs/contact.

License

skeleton is licensed under the Apache 2.0 license.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Hello

func Hello() string

Types

This section is empty.

Jump to